# Hello World

This is an example project demonstrating how to publish a python module to PyPI

## Installation

Run the following to install

...python
pip install suriyahelloworld
'''

## Useage
>>> from suriyahelloworld import say_hello
>>> say_hello("Suriya")
'Hello, Suriya!'
>>> say_hello()
'hello, World!'